@@ -7,7 +7,7 @@ RDF::Query::Plan::Union - Executable query plan for unions.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Union version 2.906.
+This document describes RDF::Query::Plan::Union version 2.910.
 
 =head1 METHODS
 
@@ -32,7 +32,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.906';
+	$VERSION	= '2.910';
 }
 
 ######################################################################
@@ -60,6 +60,7 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
+	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "BGP plan can't be executed while already open";
 	}
@@ -93,6 +94,9 @@ sub next {
 	my $row		= $iter->next;
 	if (defined($row)) {
 		$l->trace( "union row: $row" );
+		if (my $d = $self->delegate) {
+			$d->log_result( $self, $row );
+		}
 		return $row;
 	} else {
 		$self->[0]{iter}	= undef;
@@ -105,7 +109,11 @@ sub next {
 			if ($iter->state == $self->OPEN) {
 				$l->trace( "union moving to next branch" );
 				$self->[0]{iter}	= $iter;
-				return $self->next;
+				my $bindings	= $self->next;
+				if (my $d = $self->delegate) {
+					$d->log_result( $self, $bindings );
+				}
+				return $bindings;
 			} else {
 				throw RDF::Query::Error::ExecutionError -text => "execute() on RHS of UNION failed during next()";
 			}
